const std = @import("std");

pub fn build(b: *std.Build) !void {
    const target = b.standardTargetOptions(.{});
    const optimize = b.standardOptimizeOption(.{});

    const args_dep = b.dependency("args", .{ .target = target, .optimize = optimize });
    const known_folders_dep = b.dependency("known_folders", .{});
    const ansi_term_dep = b.dependency("ansi_term", .{ .target = target, .optimize = optimize });
    const getty_dep = b.dependency("getty", .{ .target = target, .optimize = optimize });
    const getty_json_dep = b.dependency("getty_json", .{ .target = target, .optimize = optimize });

    const exe = b.addExecutable(.{
        .name = "zupper",
        .root_source_file = .{ .path = "src/main.zig" },
        .target = target,
        .optimize = optimize,
        .link_libc = true,
    });

    exe.root_module.linkSystemLibrary("archive", .{});

    exe.root_module.addImport("zig-args", args_dep.module("args"));
    exe.root_module.addImport("known-folders", known_folders_dep.module("known-folders"));
    exe.root_module.addImport("ansi-term", ansi_term_dep.module("ansi-term"));
    exe.root_module.addImport("getty", getty_dep.module("getty"));
    exe.root_module.addImport("json", getty_json_dep.module("json"));

    b.installArtifact(exe);

    const run_cmd = b.addRunArtifact(exe);
    run_cmd.step.dependOn(b.getInstallStep());
    if (b.args) |args| {
        run_cmd.addArgs(args);
    }

    const run_step = b.step("run", "Run the app");
    run_step.dependOn(&run_cmd.step);
}
