const std = @import("std");

pub const version = "0.4.0";

pub const Info = struct {};

pub const Install = struct {
    use: bool = false,

    pub const shorthands = .{
        .u = "use",
    };
};

pub const Uninstall = struct {};
pub const Unuse = struct {};
pub const Update = struct {};
pub const Use = struct {};

pub const Opts = struct {
    help: bool = false,

    pub const shorthands = .{
        .h = "help",
    };
};

pub const Args = union(enum) {
    info: Info,
    install: Install,
    uninstall: Uninstall,
    unuse: Unuse,
    update: Update,
    use: Use,
};

const help_s =
    \\=== Zupper v{[version]s} - Zig version manager ===
    \\LordMZTE <lord@mzte.de>
    \\
    \\Options:
    \\    --help, -h    show this help
    \\
    \\Subcommands:
    \\    {[a0]s} info                                 prints information about the setup
    \\    {[a0]s} install <VERSIONS...> [--use, -u]    downloads the given zig versions and optionally uses them
    \\    {[a0]s} uninstall <VERSIONS...>              uninstall the given versions
    \\    {[a0]s} unuse                                unuse the version currently in use (essentially a soft-uninstall)
    \\    {[a0]s} update [VERSIONS...]                 update the given version, or all versions if none are given
    \\    {[a0]s} use <VERSION>                        uses the given version by symlinking the compiler into $PATH
    \\
;

pub fn printHelp(alloc: std.mem.Allocator) !void {
    var stdout_buf = std.io.bufferedWriter(std.io.getStdOut().writer());
    defer stdout_buf.flush() catch {};

    var args = try std.process.argsWithAllocator(alloc);
    args.deinit();

    try stdout_buf.writer().print(help_s, .{
        .a0 = std.fs.path.basename(args.next() orelse return error.BorkedArgs),
        .version = version,
    });
}
