const std = @import("std");
const dirs = @import("../dirs.zig");
const args = @import("../args.zig");
const Args = args.Info;
const Manifest = @import("../Manifest.zig");

pub fn run(
    alloc: std.mem.Allocator,
    manifest: *Manifest,
    _: Args,
    positionals: []const [:0]const u8,
) !void {
    _ = alloc;

    if (positionals.len != 0) {
        std.log.err("expected 0 positional arguments, found {}", .{positionals.len});
        return error.Explained;
    }

    var stdout_buf = std.io.bufferedWriter(std.io.getStdOut().writer());
    const stdout = stdout_buf.writer();

    try stdout.print(
        "zupper v{s}, running on {s}\n\n",
        .{ args.version, @tagName(@import("builtin").os.tag) },
    );

    if (manifest.data.value.versions.count() == 0) {
        try stdout.writeAll("no installed versions\n");
    } else {
        try stdout.writeAll("installed versions:\n");

        var iter = manifest.data.value.versions.iterator();
        while (iter.next()) |kv| {
            try stdout.print("\t{s}\t{}\n", .{ kv.key_ptr.*, kv.value_ptr.* });
        }
    }

    try stdout_buf.flush();
}
