const std = @import("std");
const dirs = @import("../dirs.zig");
const net = @import("../net.zig");
const Args = @import("../args.zig").Uninstall;
const Manifest = @import("../Manifest.zig");

pub fn run(
    alloc: std.mem.Allocator,
    manifest: *Manifest,
    args: Args,
    positionals: []const [:0]const u8,
) !void {
    _ = args;

    if (positionals.len == 0) {
        std.log.err("no arguments provided! need versions to uninstall!", .{});
        return error.Explained;
    }

    const home = try dirs.zupperHome(alloc);
    defer alloc.free(home);

    for (positionals) |version| {
        if (!try dirs.isVersionInstalled(alloc, home, version)) {
            std.log.warn("version '{s}' is not installed", .{version});
            continue;
        }

        const ver_path = try std.fs.path.join(alloc, &.{ home, "installs", version });
        defer alloc.free(ver_path);

        std.log.info("deleting {s}", .{ver_path});
        manifest.removeVersion(version);
        try std.fs.cwd().deleteTree(ver_path);

        if (manifest.data.value.in_use != null and std.mem.eql(u8, manifest.data.value.in_use.?, version)) {
            try dirs.unuseCurrentVersion(alloc, manifest);
        }
    }
}
