const std = @import("std");
const at = @import("ansi-term");

pub fn log(
    comptime level: std.log.Level,
    comptime scope: @TypeOf(.EnumLiteral),
    comptime format: []const u8,
    args: anytype,
) void {
    _ = scope;

    var stdout_buf = std.io.bufferedWriter(std.io.getStdOut().writer());
    defer stdout_buf.flush() catch {};

    const stdout = stdout_buf.writer();

    const color = switch (level) {
        .debug => .Blue,
        .info => .Green,
        .warn => .Yellow,
        .err => .Red,
    };

    const prefix = switch (level) {
        .debug => "D: ",
        .info => "I: ",
        .warn => "W: ",
        .err => "E: ",
    };

    at.format.updateStyle(
        stdout,
        .{ .foreground = color, .font_style = .{ .bold = true } },
        null,
    ) catch {};
    stdout.writeAll(prefix) catch {};
    at.format.resetStyle(stdout) catch {};

    stdout.print(format ++ "\n", args) catch {};
}
