const std = @import("std");
const zig_args = @import("zig-args");
const args = @import("args.zig");
const Manifest = @import("Manifest.zig");

pub const std_options = struct {
    pub const logFn = @import("log.zig").log;
    pub const log_level = .debug;
};

pub fn main() !u8 {
    var gpa = std.heap.GeneralPurposeAllocator(.{}){};
    defer _ = gpa.deinit();
    const alloc = gpa.allocator();

    const opts = try zig_args.parseWithVerbForCurrentProcess(args.Opts, args.Args, alloc, .print);
    defer opts.deinit();

    if (opts.options.help) {
        try args.printHelp(alloc);
        return 0;
    }

    runCmd(alloc, opts) catch |e| {
        switch (e) {
            error.Explained => return 1,
            else => {
                std.log.err("==== UNEXPECTED ERROR (please report bug) ===", .{});
                return e;
            },
        }
    };

    return 0;
}

fn runCmd(alloc: std.mem.Allocator, opts: anytype) !void {
    const verb = opts.verb orelse {
        std.log.err("no verb provided!", .{});
        try args.printHelp(alloc);
        return error.Explained;
    };
    var manifest = try Manifest.load(alloc);
    defer manifest.deinit();

    switch (verb) {
        .info => |a| {
            try @import("commands/info.zig").run(alloc, &manifest, a, opts.positionals);
        },
        .install => |a| {
            try @import("commands/install.zig").run(alloc, &manifest, a, opts.positionals);
        },
        .update => |a| {
            try @import("commands/update.zig").run(alloc, &manifest, a, opts.positionals);
        },
        .use => |a| {
            try @import("commands/use.zig").run(alloc, &manifest, a, opts.positionals);
        },
        .uninstall => |a| {
            try @import("commands/uninstall.zig").run(alloc, &manifest, a, opts.positionals);
        },
        .unuse => |a| {
            try @import("commands/unuse.zig").run(alloc, &manifest, a, opts.positionals);
        },
    }

    try manifest.save();
}
